# June 29, 2021

**Date:** June 29, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-06-29/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)** 

**[Youtube Link](https://youtu.be/-aQFh8rjcdA)**

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Frederic** 
  * Plotly v5 is out (actually v5.1 has been released yesterday): update to [plotly.js v2](https://github.com/plotly/plotly.js/blob/master/CHANGELOG.md#210----2021-06-18), federated extension, single extension, lazy load plotly.js - [full changelog](https://github.com/plotly/plotly.py/releases/tag/v5.0.0).
  * [JupyterLab v3.1 beta 0](https://github.com/jupyterlab/jupyterlab/releases/tag/v3.1.0b0)
* **Isabela** [Scipy Tools Plenary session at SciPy 2021 discussion](https://discourse.jupyter.org/t/scipy-tools-plenary-session-at-scipy-2021/9567) is still available for potential project updates.
* **Nick (or Jeremy :heart:)** `jupyterlite 0.1.0a1` is up [on PyPI](https://pypi.org/project/jupyterlite/0.1.0a1/) for building your own sites with a `doit`-powered [CLI](https://jupyterlite.readthedocs.io/en/latest/cli.html). Works with many `ipywidgets`, including `plotly 5.x`
* **Kevin** [Kernel Provisioning](https://github.com/jupyter/jupyter_client/pull/612) pull request in `jupyter_client` is ready for review
* **Loïc** [jupyterlab-h5web](https://github.com/silx-kit/jupyterlab-h5web) `0.0.8` release landing this week bringing support of HDF5 external link and compression
* **Nick (or Mike :heart:)** [JEP-72: LSP integration](https://github.com/jupyter/enhancement-proposals/pull/72) is in PR
* **Matt Seal**[`nbconvert 6.1.0`](https://nbconvert.readthedocs.io/en/latest/changelog.html) was released last week. [Proposal: Transmit Cell Metadata #70](https://github.com/jupyter/enhancement-proposals/pull/70)

## Agenda Items
* **Eduardo Blancas** Short introduction to [Ploomber](https://github.com/ploomber/ploomber), an open-source library to build data pipelines with Jupyter
* :bird: [pidgy](https://github.com/deathbeds/pidgy/) demo

## Other Links Shared
- http://worrydream.com/Tangle/
- https://dagster.io/ 
- https://github.com/deathbeds/XlbsOSh_t
- https://mybinder.org/v2/gh/deathbeds/pidgy/new-parser
- https://twitter.com/CarlosHerreroB/status/1409616391527931906

## Attendees

|   Name             | Institution     | GitHub Handle                     |
|--------------------|-----------------|-----------------------------------|
| Frederic Collonval | QuantStack      | @fcollonval                       |
| Eduardo Blancas    | Ploomber        | @edublancas                       |
| Nick Bollweg       | Georgia Tech    | @bollwyvl @nrbgt                  |
| Paige Bailey       | Microsoft       | @dynamicwebpaige                  |
| Steven Silvester   | Apple           | @blink1073                        |
| Hamilton Ulmer     | Mozilla         | @hamilton                         |
| Carol Willing      | Jupyter, Noteable | @willingc                       |
| Matthew Seal       |     Noteable    | @mseal                            |
| Claudia Regio      | Microsoft       | @claudiaregio                     |
| Ian Huff           | Microsoft       |                                   |
| Alex Bozarth       |  IBM            | @ajbozarth                        |
| Ryan Spencer       | Georgia Tech    | @ryspnc                           |
| Loic Huder         | ESRF            | @loichuder                        |
| A. T. Darian       | Two Sigma       | @afshin                           |
| Wayne Decatur      | Upstate Medical | @fomightez                        |
| Michał Krassowski  |                 | @krassowski                       |
| Luciano Resende    | IBM             | @lresende                         |
| Kiersten Stokes    | IBM             | @kiersten-stokes                  |
| Tony Fast          | Quansight       | @tonyfast                         |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf                     |